ArchiveSource class final

Inheritance

Constructors

ArchiveSource({required String url, required String sha256, required String dest, int stripComponents = 1, List<String>? onlyArches})

Properties

dest String
final
hashCode int
The hash code for this object.
no setterinherited
onlyArches List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String
final
stripComponents int
final
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited