DeveloperConfig class

Developer info for metainfo <developer> element.

Constructors

DeveloperConfig({required String name, String? id})
const
DeveloperConfig.fromYaml(dynamic yaml)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Reverse-DNS id matching the app-id (e.g. "io.github.o_murphy"). Required by AppStream 1.0 / Flathub guidelines.
final
name String
Display name shown in software centres.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited